# Réponse tactile

Le plugin `touch_response` permet de travailler avec des réponses tactiles (ou des clics souris) d'une manière simple, en divisant l'écran en lignes et colonnes. Chaque réponse est encodée sous forme d'un numéro unique qui correspond au positionnement de gauche à droite et de haut en bas. Par exemple, si vous avez défini 2 colonnes et 3 lignes, l'écran sera divisé de la manière suivante en 6 régions :
	1	2
	3	4
	5	6

De la même manière, si vous avez défini 4 colonnes et 1 ligne, l'écran sera divisé horizontallement en 4 régions :
	1	2	3	4
